#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-52KySlSq94W3m3NivbWnNu
key:                  postgrest-10.1.0-52KySlSq94W3m3NivbWnNu
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  b578df96cde0f6062be5e98c8d80210f
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-52KySlSq94W3m3NivbWnNu
depends:
    HTTP-4000.5.0-KBzZkhcIDg0EA6RYEQDu68
    Ranged-sets-0.5.0-G6nNKV9lQdu3bM9uZKPNhz
    aeson-2.2.2.0-CuqyF0GV84l91XsdnO7HOm
    auto-update-0.1.6-G3jyOVKigyW5NBFTjzsPNg base-4.18.2.1
    base64-bytestring-1.2.1.0-6ahp7SfFZkd6mBBNURIRpE
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Eh88MLcrDxqA6puekTfvJo
    cassava-0.5.4.1-GFPsBYfdB5kROi5NfCslH
    configurator-pg-0.2.11-H3Ntcx9QPuS8tNIliyeyob containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-ZnqRLKZbwGJpnRkHNd2di
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-LWDa1itbzay4yRGkqKi0wb
    hasql-dynamic-statements-0.3.1.2-HBpzYRLH1DwATvECAGbWA8
    hasql-notifications-0.2.0.5-KwXUpbB6FwpD939IO1Prx7
    hasql-pool-0.8.0.2-EebMPB8xxQtDThFr1Jicr0
    hasql-transaction-1.0.1.2-CxI62FVZYrTGqCc3UsRTNa
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-1k09WZUFwaNKy3YYy34Hwy
    insert-ordered-containers-0.2.5.3-FuJUP9LBObd2bJL7HB500T
    interpolatedstring-perl6-1.0.2-HnJFBZZfZ9K32rBGdQj6s1
    jose-0.10.0.1-FK6Qmv5Hdo77ZYTpbeP2Yq
    lens-5.3.4-AIhP2tgqTtI4periiO8TOY
    lens-aeson-1.2.3-BbXdEZZYhBdIXmBXrPIoVQ mtl-2.3.1
    network-3.1.4.0-Lt0aE8CPrcjIQCbzsjcySE
    network-uri-2.6.4.2-JQnyVhRAD0FHP2QsmDrZ2X
    optparse-applicative-0.18.1.0-HIDucWLVsMnBph0dP0V3D6
    parsec-3.1.16.1 protolude-0.3.5-Gy0EPYEPLqp781Bwx1QIK3
    regex-tdfa-1.3.2.5-AvdfaJ7YsJ1IGV7skEbGGt
    retry-0.9.3.1-C6hdN5EM1bd71j2KT06hbJ
    scientific-0.3.8.1-Co1OoXRAd2pL4XpBjX62A7
    swagger2-2.8.10-3tpVUNtp7AfHU7qSjrdVqv text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-owJOmMRhDW8XCXGWMsAkD
    vault-0.3.1.6-EtxOMMmzT3MDwbX9Ul01rU
    vector-0.13.2.0-KHhvLzyWGFJKP6boEp8Bp2
    wai-3.2.4-Lrxlo0kYTiqA2TBLB2W4tv
    wai-cors-0.2.7-oeTZgXFrUY3GFq3syTnP
    wai-extra-3.1.18-AHT42vOKcZX77kwxd2jWWr
    wai-logger-2.5.0-Ehx8aTD7pmW3W8naMUwcC
    warp-3.4.0-DdJTaI7MJKm2GAnsLaCQWD

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

